==> RSTouchscreenNG-1.4.17.zip: RSTouchscreenNG/projects/pages/src/lib/settings.component.ts <==
/* (C) 2016-2023 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {Component, OnDestroy} from "@angular/core";
import {PrintersState, PrinterState, ServerState, WifiState, MessageState, ExternalCommand, RepetierState} from "binding";
import {Observable, SubscriptionLike} from "rxjs";
import {ServerAction} from "binding";
import {RSModal} from "front-ui";
import {Store} from "@ngrx/store";

@Component({
  // eslint-disable-next-line @angular-eslint/component-selector
  selector: "rs-settings",
  template: `
    <rs-page>
      <rs-side>
        <rs-sideicon title="<?php _('Menu') ?>" icon="rs-menu" link="/"></rs-sideicon>
      </rs-side>
      <rs-side *rsIfConnected="true">
        <rs-sideicon *rsIfPrinting="true" title="<?php _('Print') ?>" icon="rs rs-print" link="/print-status"></rs-sideicon>
        <div *ngIf="(server$|async).features['touch-move']">
          <rs-sideicon *rsIfPrinting="false" icon="rs rs-move-xy" title="<?php _('Move') ?>" link="/move-tool"></rs-sideicon>
        </div>
        <rs-empty-sideicon *ngIf="!(server$|async).features['touch-move']"></rs-empty-sideicon>
      </rs-side>
      <rs-side *rsIfConnected="false">
        <rs-empty-sideicon></rs-empty-sideicon>
      </rs-side>
      <rs-side>
        <div *ngIf="!(server$|async).features['touch-status']">
          <rs-sideicon *rsIfConnected="true" icon="rs rs-params" title="<?php _('Status') ?>" link="/params"></rs-sideicon>
          <rs-empty-sideicon *rsIfConnected="false"></rs-empty-sideicon>
        </div>
        <rs-empty-sideicon *ngIf="!(server$|async).features['touch-status']"></rs-empty-sideicon>
      </rs-side>
      <main>
        <rs-headline><i class="fa fa-gear"></i> <?php _('Settings') ?></rs-headline>
        <div class="content-h1" rsDrag>
          <div>
            <rs-iconlist>
              <rs-icon icon="fa fa-info-circle" title="<?php _('Info') ?>" link="/info"></rs-icon>
              <!-- <rs-icon icon="fa fa-sitemap" title="<?php _('Network') ?>" link="/network"></rs-icon> -->
              <rs-icon *ngIf="(wifi$ | async).manageable && (server$|async).features['config-network'] && (server$|async).features['touch-network']" icon="fa fa-sitemap" title="<?php _('Network') ?>" link="/wlan"></rs-icon>
              <rs-icon *ngIf="(server$|async).features['touch-language']" icon="fa fa-language" title="<?php _('Language') ?>" link="/languages"></rs-icon>
              <rs-icon *ngIf="(server$|async).features['config-gui'] && (server$|async).features['touch-screensaver']" icon="rs rs-screensaver" title="<?php _('Screensaver') ?>" link="/screensaver"></rs-icon>
              <rs-icon *ngIf="(server$|async).features['config-network'] && (server$|async).features['touch-time-format']" icon="fa fa-clock-o" title="<?php _('Time & Format') ?>" link="/timesettings"></rs-icon>
              <span *ngIf="(server$|async).features['printer-eeprom']"><rs-icon *rsIfConnected="true" icon="rs rs-eeprom-settings" title="<?php _('EEPROM') ?>" link="/eeprom"></rs-icon></span>
              <rs-icon *ngIf="(server$|async).features['hasMaintainer']" icon="fa fa-user" title="<?php _('Maintainer') ?>" link="/maintainer"></rs-icon>
            </rs-iconlist>
          </div>
        </div>
      </main>
    </rs-page>`
})
export class SettingsComponent implements OnDestroy {
  printers$: Observable<PrintersState>;
  server$: Observable<ServerState>;
  wifi$: Observable<WifiState>;
  messages$: Observable<MessageState[]>;
  commands$: Observable<ExternalCommand[]>;
  printer: PrinterState;
  printers: PrintersState;
  server: ServerState = undefined;
  shutdown: ExternalCommand = null;
  private printersSubscription: SubscriptionLike;
  private serverSubscription: SubscriptionLike;
  private commandsSubscription: SubscriptionLike;

  constructor(public serverAction: ServerAction,
              public modal: RSModal,
              private store: Store<RepetierState>) {
    this.printers$ = store.select("printers");
    this.server$ = store.select("server");
    this.wifi$ = store.select("wifi");
    this.messages$ = store.select("messages");
    this.commands$ = store.select(s => s.server.externalCommands);
    this.printersSubscription = this.printers$.subscribe((p: PrintersState) => {
      this.printers = p;
      if (p.active) {
        this.printer = p.printers[p.active];
      } else {
        this.printer = undefined;
      }
    });
    this.serverSubscription = this.server$.subscribe((s: ServerState) => {
      this.server = s;
    });
    this.commandsSubscription = this.commands$.subscribe((c: ExternalCommand[]) => {
      c.forEach(x => {
        if (x.execute.indexOf("shutdown") >= 0) {
          this.shutdown = x;
        }
      });
    });
  }

  ngOnDestroy() {
    this.printersSubscription.unsubscribe();
    this.serverSubscription.unsubscribe();
    this.commandsSubscription.unsubscribe();
  }

  restart() {
    window.location.assign(window.location.pathname + "?front=1&" + Math.random());
  }

  runCommand(cmd: ExternalCommand) {
    if (cmd.confirm) {
      this.modal.confirm("<?php _('Security Question') ?>", cmd.confirm, {}).then(
        (res) => this.serverAction.runExternalCommand(cmd), () => {
        }
      );
    } else {
      this.serverAction.runExternalCommand(cmd);
    }
  }
}

==> RSTouchscreenNG-1.4.18.zip: RSTouchscreenNG/projects/pages/src/lib/settings.component.ts <==
/* (C) 2016-2023 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {Component, OnDestroy} from "@angular/core";
import {PrintersState, PrinterState, ServerState, WifiState, MessageState, ExternalCommand, RepetierState} from "binding";
import {Observable, SubscriptionLike} from "rxjs";
import {ServerAction} from "binding";
import {RSModal} from "front-ui";
import {Store} from "@ngrx/store";

@Component({
  // eslint-disable-next-line @angular-eslint/component-selector
  selector: "rs-settings",
  template: `
    <rs-page>
      <rs-side>
        <rs-sideicon title="<?php _('Menu') ?>" icon="rs-menu" link="/"></rs-sideicon>
      </rs-side>
      <rs-side *rsIfConnected="true">
        <rs-sideicon *rsIfPrinting="true" title="<?php _('Print') ?>" icon="rs rs-print" link="/print-status"></rs-sideicon>
        <div *ngIf="(server$|async).features['touch-move']">
          <rs-sideicon *rsIfPrinting="false" icon="rs rs-move-xy" title="<?php _('Move') ?>" link="/move-tool"></rs-sideicon>
        </div>
        <rs-empty-sideicon *ngIf="!(server$|async).features['touch-move']"></rs-empty-sideicon>
      </rs-side>
      <rs-side *rsIfConnected="false">
        <rs-empty-sideicon></rs-empty-sideicon>
      </rs-side>
      <rs-side>
        <div *ngIf="(server$|async).features['touch-status']">
          <rs-sideicon *rsIfConnected="true" icon="rs rs-params" title="<?php _('Status') ?>" link="/params"></rs-sideicon>
          <rs-empty-sideicon *rsIfConnected="false"></rs-empty-sideicon>
        </div>
        <rs-empty-sideicon *ngIf="!(server$|async).features['touch-status']"></rs-empty-sideicon>
      </rs-side>
      <main>
        <rs-headline><i class="fa fa-gear"></i> <?php _('Settings') ?></rs-headline>
        <div class="content-h1" rsDrag>
          <div>
            <rs-iconlist>
              <rs-icon icon="fa fa-info-circle" title="<?php _('Info') ?>" link="/info"></rs-icon>
              <!-- <rs-icon icon="fa fa-sitemap" title="<?php _('Network') ?>" link="/network"></rs-icon> -->
              <rs-icon *ngIf="(wifi$ | async).manageable && (server$|async).features['config-network'] && (server$|async).features['touch-network']" icon="fa fa-sitemap" title="<?php _('Network') ?>" link="/wlan"></rs-icon>
              <rs-icon *ngIf="(server$|async).features['touch-language']" icon="fa fa-language" title="<?php _('Language') ?>" link="/languages"></rs-icon>
              <rs-icon *ngIf="(server$|async).features['config-gui'] && (server$|async).features['touch-screensaver']" icon="rs rs-screensaver" title="<?php _('Screensaver') ?>" link="/screensaver"></rs-icon>
              <rs-icon *ngIf="(server$|async).features['config-network'] && (server$|async).features['touch-time-format']" icon="fa fa-clock-o" title="<?php _('Time & Format') ?>" link="/timesettings"></rs-icon>
              <span *ngIf="(server$|async).features['printer-eeprom']"><rs-icon *rsIfConnected="true" icon="rs rs-eeprom-settings" title="<?php _('EEPROM') ?>" link="/eeprom"></rs-icon></span>
              <rs-icon *ngIf="(server$|async).features['hasMaintainer']" icon="fa fa-user" title="<?php _('Maintainer') ?>" link="/maintainer"></rs-icon>
            </rs-iconlist>
          </div>
        </div>
      </main>
    </rs-page>`
})
export class SettingsComponent implements OnDestroy {
  printers$: Observable<PrintersState>;
  server$: Observable<ServerState>;
  wifi$: Observable<WifiState>;
  messages$: Observable<MessageState[]>;
  commands$: Observable<ExternalCommand[]>;
  printer: PrinterState;
  printers: PrintersState;
  server: ServerState = undefined;
  shutdown: ExternalCommand = null;
  private printersSubscription: SubscriptionLike;
  private serverSubscription: SubscriptionLike;
  private commandsSubscription: SubscriptionLike;

  constructor(public serverAction: ServerAction,
              public modal: RSModal,
              private store: Store<RepetierState>) {
    this.printers$ = store.select("printers");
    this.server$ = store.select("server");
    this.wifi$ = store.select("wifi");
    this.messages$ = store.select("messages");
    this.commands$ = store.select(s => s.server.externalCommands);
    this.printersSubscription = this.printers$.subscribe((p: PrintersState) => {
      this.printers = p;
      if (p.active) {
        this.printer = p.printers[p.active];
      } else {
        this.printer = undefined;
      }
    });
    this.serverSubscription = this.server$.subscribe((s: ServerState) => {
      this.server = s;
    });
    this.commandsSubscription = this.commands$.subscribe((c: ExternalCommand[]) => {
      c.forEach(x => {
        if (x.execute.indexOf("shutdown") >= 0) {
          this.shutdown = x;
        }
      });
    });
  }

  ngOnDestroy() {
    this.printersSubscription.unsubscribe();
    this.serverSubscription.unsubscribe();
    this.commandsSubscription.unsubscribe();
  }

  restart() {
    window.location.assign(window.location.pathname + "?front=1&" + Math.random());
  }

  runCommand(cmd: ExternalCommand) {
    if (cmd.confirm) {
      this.modal.confirm("<?php _('Security Question') ?>", cmd.confirm, {}).then(
        (res) => this.serverAction.runExternalCommand(cmd), () => {
        }
      );
    } else {
      this.serverAction.runExternalCommand(cmd);
    }
  }
}
